<?php
ini_set('memory_limit', '-1');
//Este controlador manda a traer las acciones que ayudará a que el módulo realiza sus funciones(Cosmetólogo)
class ServiciosGeneralesC extends CI_Controller
{
	//Constructor que manda a traer las librerias de sesión y validación 
	//Manda a llamar el modelo 
	public function __construct()
	{
		parent::__construct();
		$this->load->model('servicios/Cosmetologo/serviciosGeneralesC_model');
		$this->load->library(array('session','form_validation'));
	}

	//Función principal que valida que el usuario este logueado
	//Manda a traer la vista principal listaServiciosGenerales_view
	//Hace la consulta para mostrar todos los servicios adicionales que esten registrados en la franquicia del usuario logueado
	public function index()
	{
		if($this->session->userdata('Rol_IdRol')==FALSE || 
			$this->session->userdata('Rol_IdRol') == '1'|| 
			$this->session->userdata('Rol_IdRol') == '2')
		{
			redirect(base_url().'acceso/acceso');
		} else {
      $data['Franquicias']=$this->serviciosGeneralesC_model->BuscarFranquicia();
	  foreach ($data['Franquicias'] as $i => $Franquicias)
      $data['Zona1']=$this->serviciosGeneralesC_model->BuscarZona1();
      foreach ($data['Zona1'] as $i => $Zona) 

     $data['Modelo1']=$this->serviciosGeneralesC_model->BuscarModelo1();
      foreach ($data['Modelo1'] as $a => $Modelo) 

      $this->db->join('tiposervicio','TipoServicio_IdTipoServicio=IdTipoServicio','inner');
      $this->db->join('modelo','Modelo_IdModelo=IdModelo','inner');
  
      $this->db->join('zona','Zona_IdZona = IdZona','inner'); 
      $this->db->where("(TipoServicio_IdTipoServicio = '2')");
      $this->db->where('Zona_IdZona',$i);
      $this->db->where('Modelo_IdModelo',$a);

      
      

		$data['consulta']=$this->db->get('serviciosgenerales')->result();

		$this->load->view('layout/headerCos');
		$this->load->view('layout/menuCosmetologo');
		$this->load->view('servicios/Cosmetologo/listaServiciosGenerales_view',$data);
		$this->load->view('layout/footer');
		}
	}

	//Funcion que manda a traer la vista agregaServicioGeneralA_view para registrar el servicio general
	

	//Funcion que muestra los datos del servicio seleccionado  
	public function servicios()
	{
		if(isset($_GET['term'])){
			$result = $this->serviciosGeneralesC_model->buscarServicioGe($_GET['term']);
			if(count($result)>0){
				foreach ($result as $row) 
					$arr_result[] = array(
						'label' => $row->NombreServicio,
						'TipoServicio' => $row->NombreTipoServicio,
						'Modelo' => $row->NombreModelo,
						'Categoria' => $row->NombreCategoria,
						'SesionesServicio' => $row->SesionesServicio,
						'Precios' => $row->PreciosServicio,
						'Descripcion' => $row->DescripcionServicio,
						'Observaciones'	=> $row->ObservacionesServicio,
						'Zona'	=> $row->NombreZona,
						'Servicios'	=> $row->IdServiciosGenerales,
						'codigo'=> $row->Codigo_Servicios,
					);
						echo json_encode($arr_result);
				}
		}
	}


	//Función que manda a traer la vista buscarServiciosGenerales_view y hace la busqueda del servicio seleccionado 



	//Función que manda a traer la vista editarServiGeneral_view con los datos del servicio seleccionado
	public function VerInformacion()
	{
		if($this->session->userdata('Rol_IdRol')==FALSE || 
			$this->session->userdata('Rol_IdRol') == '1'|| 
			$this->session->userdata('Rol_IdRol') == '2')
		{
			redirect(base_url().'acceso/acceso');
		} else {
		$id= $this->uri->segment(5);
		$obtenerenlace = $this->serviciosGeneralesC_model->obtenerenlace($id);
		if($obtenerenlace != FALSE){
			foreach ($obtenerenlace->result() as $fila) {
				$IdServiciosGenerales=$fila->IdServiciosGenerales;
				$Modelo_IdModelo=$fila->Modelo_IdModelo;
				$NombreServicio = $fila->NombreServicio;
				$TipoServicio_IdTipoServicio=$fila->TipoServicio_IdTipoServicio;
				$Categoria_IdCategoria=$fila->Categoria_IdCategoria;
				$SesionesServicio=$fila->SesionesServicio;
				$PreciosServicio=$fila->PreciosServicio;
				$DescripcionServicio=$fila->DescripcionServicio;
				$ObservacionesServicio=$fila->ObservacionesServicio;
				$Zona_IdZona=$fila->Zona_IdZona;
			}
			$data = array(
				'IdServiciosGenerales' => $IdServiciosGenerales,
				'Modelo_IdModelo' => $Modelo_IdModelo,
				'NombreServicio' => $NombreServicio,
				'TipoServicio_IdTipoServicio' => $TipoServicio_IdTipoServicio,
				'Categoria_IdCategoria' => $Categoria_IdCategoria,	
				'SesionesServicio' => $SesionesServicio,
				'PreciosServicio' => $PreciosServicio,
			    'DescripcionServicio' => $DescripcionServicio,
			    'ObservacionesServicio' => $ObservacionesServicio,
			    'Zona_IdZona' => $Zona_IdZona);
			}else{
				$data ='';
				return FALSE;
			}
		}
		$data['ReModelo']=$this->serviciosGeneralesC_model->BuscarModelo();
		$data['ReTipoS']=$this->serviciosGeneralesC_model->BuscarTipoS();
	    $data['ReCategoria']=$this->serviciosGeneralesC_model->BuscarCategoria();
	    $data['ReZona']=$this->serviciosGeneralesC_model->BuscarZona();
		$this->load->view('layout/headerCos');
		$this->load->view('layout/menuCosmetologo');
		$this->load->view('servicios/Cosmetologo/editarServiGeneral_view',$data);
		$this->load->view('layout/footer');
	}


	//Función que guarda los datos actualizados del servicio
	public function editarenlace()
	{
		$IdServiciosGenerales= $this -> uri->segment(5);
		$data=array(
			'IdServiciosGenerales' => $this ->input ->post('IdServiciosGenerales', true),
			'Modelo_IdModelo' => $this ->input ->post('Modelo_IdModelo', true),
			'NombreServicio' => $this ->input ->post('NombreServicio', true),
			'TipoServicio_IdTipoServicio' => $this ->input->post('TipoServicio_IdTipoServicio', true),
			'Categoria_IdCategoria' => $this ->input->post('Categoria_IdCategoria', true),
			'Sesiones' => $this ->input->post('Sesiones', true),
			'PreciosServicios' => $this ->input ->post('PreciosServicios', true),
			'Descripcion' => $this ->input->post('Descripcion', true),
			'Observaciones' => $this ->input ->post('Observaciones', true),
			'Zona_IdZona' => $this ->input ->post('Zona_IdZona', true)
			);
		$this->serviciosGeneralesC_model->editarenlace($IdServiciosGenerales, $data);
	}

	


	//Función que muestra el tipo de modelo 
	public function MostrarModelo()
	{
		$options ="";
		if($this->input->post('IdModelo')){
			$IdTipo=$this->input->post('IdModelo');
			$Nombre=$this->serviciosGeneralesC_model->BuscarModelo($IdTipo);
			foreach ($Nombre as $fila) {
				?>
                <option value="<?php echo $fila->id ?>"><?php echo $tipo_name ?></option>
                <?php
			}
		}
	}
	
	//Función que muestra el tipo de servicio
	public function MostrarTipoS()
	{
		$options ="";
		if($this->input->post('IdTipoServicio')){
			$IdTipo=$this->input->post('IdTipoServicio');
			$Nombre=$this->serviciosGeneralesC_model->BuscarTipoS($IdTipo);
			foreach ($Nombre as $fila) {
				?>
                <option value="<?php echo $fila->id ?>"><?php echo $tipo_name ?></option>
                <?php
			}
		}
	}

		//Función que muestra el tipo de categoria
	public function MostrarCategoria()
	{
		$options ="";
		if($this->input->post('IdCategoria')){
			$IdCategoria=$this->input->post('IdCategoria');
			$NombreCategoria=$this->serviciosGeneralesC_model->BuscarCategoria($IdCategoria);
			foreach ($Nombre as $fila) {
				?>
                <option value="<?php echo $fila->id ?>"><?php echo $categoria_name ?></option>
                <?php
			}
		}
	}

	//Función que muestra la zona
	public function MostrarZona()
	{
		$options ="";
		if($this->input->post('IdZona')){
			$IdZona=$this->input->post('IdZona');
			$Nombre=$this->serviciosGeneralesC_model->BuscarZona($IdZona);
			foreach ($Nombre as $fila) {
				?>
                <option value="<?php echo $fila->id ?>"><?php echo $zona_name ?></option>
                <?php
			}
		}
	}


	//Función que muestra la franquicia del usuario logueado
	public function MostrarFranquicia()
	{
		$options ="";
		if($this->input->post('IdFranquicias')){
			$IdFranquicias=$this->input->post('IdFranquicias');
			$NombreFranquicia=$this->serviciosGeneralesC_model->BuscarFranquicia($IdFranquicias);
			foreach ($Nombre as $fila) {
				?>
                <option value="<?php echo $fila->id ?>"><?php echo $franquicia_name ?></option>
                <?php
			}
		}
	}

	//Fución que muestra los servicios registrados 
	public function MostrarServicio()
	{
		$options ="";
		if($this->input->post('IdServiciosGenerales')){
			$IdServiciosGenerales=$this->input->post('IdServiciosGenerales');
			$NombreServicio=$this->serviciosGeneralesC_model->BuscarServicio($IdServiciosGenerales);
			foreach ($NombreProducto as $fila) {
				?>
                <option value="<?php echo $fila->id ?>"><?php echo $categoria_name ?></option>
                <?php
			}
		}
	}
	
	//Función que muestra el usuario logueado
	public function MostrarUsuario()
	{
		$options ="";
		if($this->input->post('IdUsuarios')){
			$IdUsuarios=$this->input->post('IdUsuarios');
			$NombreUsuario=$this->serviciosGeneralesC_model->BuscarUsuario($IdUsuarios);
			foreach ($Nombre as $fila) {
				?>
                <option value="<?php echo $fila->id ?>"></option>
                <?php
			}
		}
	}	
}